﻿Imports ThinkGeo.MapSuite.Core
Imports ThinkGeo.MapSuite.DesktopEdition
Public Class frmLegendProps
   Public Property Legend As LegendPrinterLayer
   Public Property PageLayout As WinformsMap
   Public Sub New(oForm As Form, oPageLayout As WinformsMap)

      ' This call is required by the designer.
      InitializeComponent()

      ' Add any initialization after the InitializeComponent() call.
      'Me.SetTopLevel(False)
      Me.Owner = oForm
      PageLayout = oPageLayout
   End Sub
   Private Function mGetPrinterOverlay() As PrinterInteractiveOverLay
      For Each oPrinterOverlay In PageLayout.InteractiveOverlays
         If TypeOf oPrinterOverlay Is PrinterInteractiveOverLay Then
            Return CType(oPrinterOverlay, PrinterInteractiveOverLay)
         End If
      Next oPrinterOverlay
      Return Nothing
   End Function

   Private Sub mAddLegend()
      Dim moPrinterOverlay As PrinterInteractiveOverLay = mGetPrinterOverlay()
      Dim dLegendItemWidth As Single = CSng(txtLegendItemWidth.Text)
      Dim dLegendWidth As Single = CSng(txtLegendWidth.Text)
      Dim dLegendheight As Single = CSng(txtLegendHeight.Text)
      Dim oTitle As LegendItem
      Dim oLegendItem As LegendItem

      '***** Create the LegendPrinterLayer and add the LegendItems.
      Legend = New LegendPrinterLayer()

      Legend.BackgroundMask = AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.White, GeoColor.SimpleColors.Black, 1)

      '***** Create a legend item for the title.
      oTitle = New LegendItem()
      mSetLegendItemProps(oTitle, "Map Legend")

      oTitle.TextStyle = New TextStyle("Map Legend",
                                      New GeoFont("Arial", CInt(txtTitleFontSize.Text), DrawingFontStyles.Bold),
                                      New GeoSolidBrush(GeoColor.SimpleColors.Black))
      Legend.Title = oTitle

      Dim dPix As Double = CreateGraphics.DpiX

      Legend.Height = dLegendheight
      Legend.Width = dLegendWidth


      Legend.LegendItems.Clear()
      For Each oItem In lstItems.Items
         oLegendItem = New LegendItem
         mSetLegendItemProps(oLegendItem, oItem.ToString)
         Legend.LegendItems.Add("LegendItem_" & (Legend.LegendItems.Count + 1).ToString, oLegendItem)
      Next oItem

      moPrinterOverlay = mGetPrinterOverlay()

      If moPrinterOverlay.PrinterLayers.Contains("Legend") Then
         moPrinterOverlay.PrinterLayers.Remove("Legend")
      End If
      moPrinterOverlay.PrinterLayers.Add("Legend", Legend)


      Legend.ResizeMode = PrinterResizeMode.Resizable
      Legend.SetPosition(dLegendWidth / dPix, dLegendheight / dPix, New PointShape(-2, -3.5), PrintingUnit.Inch)



      PageLayout.Refresh()


   End Sub
   Private Sub mSetLegendItemProps(oLegendItem As LegendItem, sText As String)
      With oLegendItem
         .Height = CSng(txtLegendItemHeight.Text)
         .Width = CSng(txtLegendItemWidth.Text)

         .LeftPadding = CSng(txtLeftPadding.Text)
         .RightPadding = CSng(txtRightPadding.Text)
         .TopPadding = CSng(txtTopPadding.Text)
         .BottomPadding = CSng(txtBottomPadding.Text)

         .ImageHeight = CSng(txtImageHeight.Text)
         .ImageWidth = CSng(txtImageWidth.Text)

         .ImageLeftPadding = CSng(txtImageLeftPadding.Text)
         .ImageRightPadding = CSng(txtImageRightPaddint.Text)
         .ImageTopPadding = CSng(txtImageTopPadding.Text)
         .ImageBottomPadding = CSng(txtImageBottomPadding.Text)

         .TextTopPadding = CSng(txtTextTopPadding.Text)
         .TextBottomPadding = CSng(txtTextBottomPadding.Text)
         .TextLeftPadding = CSng(txtTextLeftPadding.Text)
         .TextRightPadding = CSng(txtTextRightPadding.Text)


         .ImageStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.GetRandomGeoColor(RandomColorType.Bright), GeoColor.SimpleColors.Black, 1)
         .TextStyle = New TextStyle(sText, New GeoFont("Arial", CInt(txtItemFontSize.Text)), New GeoSolidBrush(GeoColor.SimpleColors.Black))
         .BackgroundMask = AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.Transparent, GeoColor.SimpleColors.Black, 1)

      End With

   End Sub
   Private Sub btn1_Click(sender As Object, e As System.EventArgs) Handles btnApply.Click
      mAddLegend()
   End Sub

   Private Sub frmLegendProps_Load(sender As Object, e As System.EventArgs) Handles Me.Load
      lstItems.Items.Clear()
      With lstItems
         .Items.Add("States")
         .Items.Add("Counties")
         .Items.Add("Tracts")
         .Items.Add("Habitat Of Large and Slow Moving Wildebeasts")
      End With

      Dim oLegendItem As New LegendItem

      With oLegendItem

         txtBottomPadding.Text = .BottomPadding.ToString
         txtTopPadding.Text = .TopPadding.ToString
         txtLeftPadding.Text = .LeftPadding.ToString
         txtRightPadding.Text = .RightPadding.ToString

         txtLegendItemHeight.Text = .Height.ToString
         txtImageBottomPadding.Text = .ImageBottomPadding.ToString
         txtImageHeight.Text = .ImageHeight.ToString
         txtImageLeftPadding.Text = .ImageLeftPadding.ToString
         txtImageRightPaddint.Text = .ImageRightPadding.ToString
         txtImageTopPadding.Text = .ImageTopPadding.ToString
         txtImageWidth.Text = .ImageWidth.ToString
         txtTextBottomPadding.Text = .TextBottomPadding.ToString
         txtTextLeftPadding.Text = .TextLeftPadding.ToString
         txtTextRightPadding.Text = .TextRightPadding.ToString
         txtTextTopPadding.Text = .TextTopPadding.ToString
      End With

   End Sub

   Private Sub btnAddItem_Click(sender As System.Object, e As System.EventArgs) Handles btnAddItem.Click
      lstItems.Items.Add(txtItem.Text)
   End Sub

   Private Sub btnRemoveItem_Click(sender As System.Object, e As System.EventArgs) Handles btnRemoveItem.Click
      If lstItems.SelectedIndex <> -1 Then
         lstItems.Items.Remove(lstItems.SelectedItem.ToString)
      End If

   End Sub

   Private Sub btnCalcHeight_Click(sender As System.Object, e As System.EventArgs) Handles btnCalcHeight.Click
      Dim dHeight As Double

      If Not Legend Is Nothing Then
         dHeight = Legend.Title.Height + Legend.Title.TopPadding + Legend.Title.BottomPadding + 1
         For Each oItem As LegendItem In Legend.LegendItems
            dHeight += oItem.Height + oItem.TopPadding + oItem.BottomPadding + 1
         Next oItem
         txtCalcHeight.Text = dHeight.ToString
      End If
   End Sub
End Class